module.exports = defineTest({
	description: 'allows paths to be set as an output option',
	command: 'rollup --config rollup.config.js'
});
